@@ -1,3 +1,4 @@
+# DEPRECATED
 Puppet::Type.newtype(:glance_registry_config) do
 
   ensurable
@@ -46,12 +47,8 @@ Puppet::Type.newtype(:glance_registry_config) do
     defaultto('<SERVICE DEFAULT>')
   end
 
-  autorequire(:package) do
-    if Facter.value(:osfamily) == 'Debian'
-      'glance-registry'
-    elsif Facter.value(:osfamily) == 'RedHat'
-      'openstack-glance'
-    end
+  autorequire(:anchor) do
+    ['glance::install::end']
   end
 
 end
