@@ -9,78 +9,76 @@ describe 'glance::api' do
 
   let :default_params do
     {
-      :bind_host                => '<SERVICE DEFAULT>',
-      :bind_port                => '9292',
-      :auth_strategy            => 'keystone',
-      :enabled                  => true,
-      :manage_service           => true,
-      :backlog                  => '<SERVICE DEFAULT>',
-      :workers                  => '7',
-      :show_image_direct_url    => '<SERVICE DEFAULT>',
+      :bind_host                      => '<SERVICE DEFAULT>',
+      :bind_port                      => '9292',
+      :auth_strategy                  => 'keystone',
+      :enabled                        => true,
+      :manage_service                 => true,
+      :backlog                        => '<SERVICE DEFAULT>',
+      :workers                        => '7',
+      :show_image_direct_url          => '<SERVICE DEFAULT>',
       :filesystem_store_metadata_file => '<SERVICE DEFAULT>',
-      :filesystem_store_file_perm => '<SERVICE DEFAULT>',
-      :location_strategy        => '<SERVICE DEFAULT>',
-      :purge_config             => false,
-      :delayed_delete           => '<SERVICE DEFAULT>',
-      :scrub_time               => '<SERVICE DEFAULT>',
-      :image_cache_dir          => '/var/lib/glance/image-cache',
-      :image_import_plugins     => '<SERVICE DEFAULT>',
+      :filesystem_store_file_perm     => '<SERVICE DEFAULT>',
+      :location_strategy              => '<SERVICE DEFAULT>',
+      :purge_config                   => false,
+      :delayed_delete                 => '<SERVICE DEFAULT>',
+      :scrub_time                     => '<SERVICE DEFAULT>',
+      :image_cache_dir                => '/var/lib/glance/image-cache',
+      :image_import_plugins           => '<SERVICE DEFAULT>',
       :image_conversion_output_format => '<SERVICE DEFAULT>',
-      :inject_metadata_properties => '<SERVICE DEFAULT>',
-      :ignore_user_roles        => '<SERVICE DEFAULT>',
-      :enabled_import_methods   => '<SERVICE DEFAULT>',
-      :node_staging_uri         => '<SERVICE DEFAULT>',
-      :image_member_quota       => '<SERVICE DEFAULT>',
-      :image_cache_stall_time   => '<SERVICE DEFAULT>',
-      :image_cache_max_size     => '<SERVICE DEFAULT>',
-      :pipeline                 => 'keystone',
-      :task_time_to_live        => '<SERVICE DEFAULT>',
-      :task_executor            => '<SERVICE DEFAULT>',
-      :task_work_dir            => '<SERVICE DEFAULT>',
-      :taskflow_engine_mode     => '<SERVICE DEFAULT>',
-      :taskflow_max_workers     => '<SERVICE DEFAULT>',
-      :conversion_format        => '<SERVICE DEFAULT>',
-      :enable_v1_api            => false,
-      :enable_v2_api            => '<SERVICE DEFAULT>',
-      :sync_db                  => true,
-      :limit_param_default      => '<SERVICE DEFAULT>',
-      :api_limit_max            => '<SERVICE DEFAULT>',
+      :inject_metadata_properties     => '<SERVICE DEFAULT>',
+      :ignore_user_roles              => '<SERVICE DEFAULT>',
+      :enabled_import_methods         => '<SERVICE DEFAULT>',
+      :node_staging_uri               => '<SERVICE DEFAULT>',
+      :image_member_quota             => '<SERVICE DEFAULT>',
+      :image_cache_stall_time         => '<SERVICE DEFAULT>',
+      :image_cache_max_size           => '<SERVICE DEFAULT>',
+      :cache_prefetcher_interval      => '<SERVICE DEFAULT>',
+      :disk_formats                   => '<SERVICE DEFAULT>',
+      :pipeline                       => 'keystone',
+      :task_time_to_live              => '<SERVICE DEFAULT>',
+      :task_executor                  => '<SERVICE DEFAULT>',
+      :task_work_dir                  => '<SERVICE DEFAULT>',
+      :taskflow_engine_mode           => '<SERVICE DEFAULT>',
+      :taskflow_max_workers           => '<SERVICE DEFAULT>',
+      :conversion_format              => '<SERVICE DEFAULT>',
+      :sync_db                        => true,
+      :limit_param_default            => '<SERVICE DEFAULT>',
+      :api_limit_max                  => '<SERVICE DEFAULT>',
     }
   end
 
   shared_examples_for 'glance::api' do
 
     [{
-        :bind_host                => '127.0.0.1',
-        :bind_port                => '9222',
-        :registry_host            => '127.0.0.1',
-        :registry_port            => '9111',
-        :registry_client_protocol => 'https',
-        :auth_strategy            => 'not_keystone',
-        :enabled                  => false,
-        :backlog                  => '4095',
-        :workers                  => '5',
-        :show_image_direct_url    => true,
-        :show_multiple_locations  => true,
+        :bind_host                      => '127.0.0.1',
+        :bind_port                      => '9222',
+        :auth_strategy                  => 'not_keystone',
+        :enabled                        => false,
+        :backlog                        => '4095',
+        :workers                        => '5',
+        :show_image_direct_url          => true,
+        :show_multiple_locations        => true,
         :filesystem_store_metadata_file => '/etc/glance/glance-metadata-file.conf',
-        :filesystem_store_file_perm => '0644',
-        :location_strategy        => 'store_type',
-        :delayed_delete           => 'true',
-        :scrub_time               => '10',
-        :image_cache_dir          => '/tmp/glance',
-        :image_import_plugins     => 'image_conversion',
+        :filesystem_store_file_perm     => '0644',
+        :location_strategy              => 'store_type',
+        :delayed_delete                 => 'true',
+        :scrub_time                     => '10',
+        :image_cache_dir                => '/tmp/glance',
+        :image_import_plugins           => 'image_conversion',
         :image_conversion_output_format => 'raw',
-        :inject_metadata_properties => 'key:val',
-        :ignore_user_roles        => 'admin',
-        :enabled_import_methods   => 'glance-direct,web-download',
-        :node_staging_uri         => '/tmp/staging',
-        :image_member_quota       => '128',
-        :image_cache_stall_time   => '10',
-        :image_cache_max_size     => '10737418240',
-        :pipeline                 => 'keystone2',
-        :sync_db                  => false,
-        :limit_param_default      => '10',
-        :api_limit_max            => '10',
+        :inject_metadata_properties     => 'key:val',
+        :ignore_user_roles              => 'admin',
+        :enabled_import_methods         => 'glance-direct,web-download',
+        :node_staging_uri               => '/tmp/staging',
+        :image_member_quota             => '128',
+        :image_cache_stall_time         => '10',
+        :image_cache_max_size           => '10737418240',
+        :cache_prefetcher_interval      => '300',
+        :pipeline                       => 'keystone2',
+        :sync_db                        => false,
+        :limit_param_default            => '10',
+        :api_limit_max                  => '10',
       }
     ].each do |param_set|
 
@@ -120,9 +118,6 @@ describe 'glance::api' do
           [
             'bind_host',
             'bind_port',
-            'registry_host',
-            'registry_port',
-            'registry_client_protocol',
             'show_image_direct_url',
             'show_multiple_locations',
             'location_strategy',
@@ -131,10 +126,9 @@ describe 'glance::api' do
             'image_cache_dir',
             'image_cache_stall_time',
             'image_cache_max_size',
+            'cache_prefetcher_interval',
             'node_staging_uri',
             'image_member_quota',
-            'enable_v1_api',
-            'enable_v2_api',
             'limit_param_default',
             'api_limit_max',
           ].each do |config|
@@ -163,8 +157,6 @@ describe 'glance::api' do
 
         it 'is_expected.to lay down default cache config' do
           [
-            'registry_host',
-            'registry_port',
             'image_cache_dir',
             'image_cache_stall_time',
             'image_cache_max_size',
@@ -195,9 +187,10 @@ describe 'glance::api' do
           is_expected.to contain_glance_api_config('DEFAULT/ca_file').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_glance_api_config('DEFAULT/cert_file').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_glance_api_config('DEFAULT/key_file').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_glance_api_config('DEFAULT/registry_client_ca_file').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_glance_api_config('DEFAULT/registry_client_cert_file').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_glance_api_config('DEFAULT/registry_client_key_file').with_value('<SERVICE DEFAULT>')
+        end
+
+        it 'is_expected.to have no disk_formats set' do
+          is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('<SERVICE DEFAULT>')
         end
 
         it 'passes purge to resource' do
@@ -291,9 +284,6 @@ describe 'glance::api' do
           :ca_file                   => '/tmp/ca_file',
           :cert_file                 => '/tmp/cert_file',
           :key_file                  => '/tmp/key_file',
-          :registry_client_ca_file   => '/tmp/registry_ca_file',
-          :registry_client_key_file  => '/tmp/registry_key_file',
-          :registry_client_cert_file => '/tmp/registry_cert_file',
         })
       end
 
@@ -301,9 +291,18 @@ describe 'glance::api' do
         it { is_expected.to contain_glance_api_config('DEFAULT/ca_file').with_value('/tmp/ca_file') }
         it { is_expected.to contain_glance_api_config('DEFAULT/cert_file').with_value('/tmp/cert_file') }
         it { is_expected.to contain_glance_api_config('DEFAULT/key_file').with_value('/tmp/key_file') }
-        it { is_expected.to contain_glance_api_config('DEFAULT/registry_client_ca_file').with_value('/tmp/registry_ca_file') }
-        it { is_expected.to contain_glance_api_config('DEFAULT/registry_client_key_file').with_value('/tmp/registry_key_file') }
-        it { is_expected.to contain_glance_api_config('DEFAULT/registry_client_cert_file').with_value('/tmp/registry_cert_file') }
+      end
+    end
+
+    describe 'with disk_formats option' do
+      let :params do
+        default_params.merge({
+          :disk_formats => 'raw,iso',
+        })
+      end
+
+      context 'with disk_formats option' do
+        it { is_expected.to contain_glance_api_config('image_format/disk_formats').with_value('raw,iso') }
       end
     end
 
