@@ -7,6 +7,7 @@ describe 'glance::backend::rbd' do
       it { should contain_glance_api_config('glance_store/rbd_store_pool').with_value('<SERVICE DEFAULT>') }
       it { should contain_glance_api_config('glance_store/rbd_store_ceph_conf').with_value('<SERVICE DEFAULT>') }
       it { should contain_glance_api_config('glance_store/rbd_store_chunk_size').with_value('<SERVICE DEFAULT>') }
+      it { should contain_glance_api_config('glance_store/rbd_thin_provisioning').with_value('<SERVICE DEFAULT>') }
       it { should contain_glance_api_config('glance_store/rados_connect_timeout').with_value('<SERVICE DEFAULT>')}
       it { should contain_glance_api_config('glance_store/rbd_store_user').with_value('<SERVICE DEFAULT>')}
 
@@ -21,6 +22,7 @@ describe 'glance::backend::rbd' do
         {
           :rbd_store_user        => 'user',
           :rbd_store_chunk_size  => '2',
+          :rbd_thin_provisioning => 'true',
           :package_ensure        => 'latest',
           :rados_connect_timeout => '30',
         }
@@ -28,6 +30,7 @@ describe 'glance::backend::rbd' do
 
       it { should contain_glance_api_config('glance_store/rbd_store_user').with_value('user') }
       it { should contain_glance_api_config('glance_store/rbd_store_chunk_size').with_value('2') }
+      it { should contain_glance_api_config('glance_store/rbd_thin_provisioning').with_value('true') }
       it { should contain_glance_api_config('glance_store/rados_connect_timeout').with_value('30')}
 
       it { should contain_package('python-ceph').with(
