@@ -14,9 +14,9 @@ describe 'glance::db::mysql' do
       end
 
       it { is_expected.to contain_openstacklib__db__mysql('glance').with(
-        :password_hash => '*41C910F70EB213CF4CB7B2F561B4995503C0A87B',
-        :charset       => 'utf8',
-        :collate       => 'utf8_general_ci',
+        :password => 'glancepass1',
+        :charset  => 'utf8',
+        :collate  => 'utf8_general_ci',
       )}
 
     end
@@ -24,16 +24,16 @@ describe 'glance::db::mysql' do
     describe "overriding default params" do
       let :params do
         {
-          :password       => 'glancepass2',
-          :dbname         => 'glancedb2',
-          :charset        => 'utf8',
+          :password => 'glancepass2',
+          :dbname   => 'glancedb2',
+          :charset  => 'utf8',
         }
       end
 
       it { is_expected.to contain_openstacklib__db__mysql('glance').with(
-        :password_hash => '*6F9A1CB9BD83EE06F3903BDFF9F4188764E694CA',
-        :dbname        => 'glancedb2',
-        :charset       => 'utf8'
+        :password => 'glancepass2',
+        :dbname   => 'glancedb2',
+        :charset  => 'utf8'
       )}
 
     end
@@ -41,9 +41,9 @@ describe 'glance::db::mysql' do
     describe "overriding allowed_hosts param to array" do
       let :params do
         {
-          :password       => 'glancepass2',
-          :dbname         => 'glancedb2',
-          :allowed_hosts  => ['127.0.0.1','%']
+          :password      => 'glancepass2',
+          :dbname        => 'glancedb2',
+          :allowed_hosts => ['127.0.0.1','%']
         }
       end
 
@@ -52,9 +52,9 @@ describe 'glance::db::mysql' do
     describe "overriding allowed_hosts param to string" do
       let :params do
         {
-          :password       => 'glancepass2',
-          :dbname         => 'glancedb2',
-          :allowed_hosts  => '192.168.1.1'
+          :password      => 'glancepass2',
+          :dbname        => 'glancedb2',
+          :allowed_hosts => '192.168.1.1'
         }
       end
 
@@ -63,9 +63,9 @@ describe 'glance::db::mysql' do
     describe "overriding allowed_hosts param equals to host param " do
       let :params do
         {
-          :password       => 'glancepass2',
-          :dbname         => 'glancedb2',
-          :allowed_hosts  => '127.0.0.1'
+          :password      => 'glancepass2',
+          :dbname        => 'glancedb2',
+          :allowed_hosts => '127.0.0.1'
         }
       end
     end
