@@ -129,7 +129,7 @@ describe 'glance::keystone::auth' do
     describe 'when configuring glance-api and the keystone endpoint' do
       let :pre_condition do
         "class { 'glance::api::authtoken': password => 'test' }
-         include ::glance::api"
+         include glance::api"
       end
 
       let :params do
